@@ -10,19 +10,24 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
-from oslotest import base as oslo_test_base
+import os
+from unittest import mock
+
+from sqlalchemy.engine import url as sqla_url
 from sqlalchemy import exc as sa_exc
 from sqlalchemy import inspect
 from sqlalchemy import schema
 from sqlalchemy import types
 
 from oslo_db import exception
+from oslo_db.sqlalchemy import enginefacade
 from oslo_db.sqlalchemy import provision
-from oslo_db.sqlalchemy import test_base
+from oslo_db.sqlalchemy import test_fixtures
+from oslo_db.tests import base as test_base
+from oslo_db.tests.sqlalchemy import base as db_test_base
 
 
-class DropAllObjectsTest(test_base.DbTestCase):
+class DropAllObjectsTest(db_test_base._DbTestCase):
 
     def setUp(self):
         super(DropAllObjectsTest, self).setUp()
@@ -66,7 +71,8 @@ class DropAllObjectsTest(test_base.DbTestCase):
             set(insp.get_table_names())
         )
 
-        self.db.backend.drop_all_objects(self.engine)
+        self._get_default_provisioned_db().\
+            backend.drop_all_objects(self.engine)
 
         insp = inspect(self.engine)
         self.assertEqual(
@@ -75,7 +81,7 @@ class DropAllObjectsTest(test_base.DbTestCase):
         )
 
 
-class BackendNotAvailableTest(oslo_test_base.BaseTestCase):
+class BackendNotAvailableTest(test_base.BaseTestCase):
     def test_no_dbapi(self):
         backend = provision.Backend(
             "postgresql", "postgresql+nosuchdbapi://hostname/dsn")
@@ -132,82 +138,54 @@ class BackendNotAvailableTest(oslo_test_base.BaseTestCase):
 
 
 class MySQLDropAllObjectsTest(
-        DropAllObjectsTest, test_base.MySQLOpportunisticTestCase):
+    DropAllObjectsTest, db_test_base._MySQLOpportunisticTestCase,
+):
     pass
 
 
 class PostgreSQLDropAllObjectsTest(
-        DropAllObjectsTest, test_base.PostgreSQLOpportunisticTestCase):
+    DropAllObjectsTest, db_test_base._PostgreSQLOpportunisticTestCase,
+):
     pass
 
 
-class RetainSchemaTest(oslo_test_base.BaseTestCase):
-    DRIVER = "sqlite"
+class AdHocURLTest(test_base.BaseTestCase):
+    def test_sqlite_setup_teardown(self):
 
-    def setUp(self):
-        super(RetainSchemaTest, self).setUp()
+        fixture = test_fixtures.AdHocDbFixture("sqlite:///foo.db")
 
-        metadata = schema.MetaData()
-        self.test_table = schema.Table(
-            'test_table', metadata,
-            schema.Column('x', types.Integer),
-            schema.Column('y', types.Integer),
-            mysql_engine='InnoDB'
+        fixture.setUp()
+
+        self.assertEqual(
+            enginefacade._context_manager._factory._writer_engine.url,
+            sqla_url.make_url("sqlite:///foo.db")
+            )
+
+        self.assertTrue(os.path.exists("foo.db"))
+        fixture.cleanUp()
+
+        self.assertFalse(os.path.exists("foo.db"))
+
+    def test_mysql_setup_teardown(self):
+        try:
+            mysql_backend = provision.Backend.backend_for_database_type(
+                "mysql")
+        except exception.BackendNotAvailable:
+            self.skipTest("mysql backend not available")
+
+        mysql_backend.create_named_database("adhoc_test")
+        self.addCleanup(
+            mysql_backend.drop_named_database, "adhoc_test"
+        )
+        url = mysql_backend.provisioned_database_url("adhoc_test")
+
+        fixture = test_fixtures.AdHocDbFixture(url)
+
+        fixture.setUp()
+
+        self.assertEqual(
+            enginefacade._context_manager._factory._writer_engine.url,
+            url
         )
 
-        def gen_schema(engine):
-            metadata.create_all(engine, checkfirst=False)
-        self._gen_schema = gen_schema
-
-    def test_once(self):
-        self._run_test()
-
-    def test_twice(self):
-        self._run_test()
-
-    def _run_test(self):
-        try:
-            database_resource = provision.DatabaseResource(self.DRIVER)
-        except exception.BackendNotAvailable:
-            self.skip("database not available")
-
-        schema_resource = provision.SchemaResource(
-            database_resource, self._gen_schema)
-        transaction_resource = provision.TransactionResource(
-            database_resource, schema_resource)
-
-        engine = transaction_resource.getResource()
-
-        with engine.connect() as conn:
-            rows = conn.execute(self.test_table.select())
-            self.assertEqual([], rows.fetchall())
-
-            trans = conn.begin()
-            conn.execute(
-                self.test_table.insert(),
-                {"x": 1, "y": 2}
-            )
-            trans.rollback()
-
-            rows = conn.execute(self.test_table.select())
-            self.assertEqual([], rows.fetchall())
-
-            trans = conn.begin()
-            conn.execute(
-                self.test_table.insert(),
-                {"x": 2, "y": 3}
-            )
-            trans.commit()
-
-            rows = conn.execute(self.test_table.select())
-            self.assertEqual([(2, 3)], rows.fetchall())
-
-        transaction_resource.finishedWith(engine)
-
-
-class MySQLRetainSchemaTest(RetainSchemaTest):
-    DRIVER = "mysql"
-
-
-class PostgresqlRetainSchemaTest(RetainSchemaTest):
-    DRIVER = "postgresql"
+        fixture.cleanUp()
